package
Version:
v1.4.1
Opens a new window with list of versions in this module.
Published: Apr 23, 2026
License: Unlicense
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
package uf2 implements the UF2 file format.
const (
FamilyRP2350ARMSigned FamilyID = 0xe48bff59
)
type Reader struct {
StartAddr uint32
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.